@@ -9,6 +9,12 @@ describe 'tempest' do
     end
 
     context 'without parameters' do
+      let :params do
+        {
+          :configure_networks => false,
+        }
+      end
+
       describe "should raise error" do
         it { expect { is_expected.to contain_class('tempest::params') }.to raise_error(Puppet::Error, /A value for either image_name or image_ref/) }
       end
@@ -16,7 +22,10 @@ describe 'tempest' do
 
     context 'with image_name parameters' do
       let :params do
-        { :image_name => 'image_name' }
+        {
+          :configure_networks => false,
+          :image_name         => 'image_name'
+        }
       end
 
       describe "should raise error" do
@@ -26,8 +35,11 @@ describe 'tempest' do
 
     context 'with image_ref parameters' do
       let :params do
-        { :image_ref     => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b',
-          :image_ref_alt => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b' }
+        {
+          :configure_networks => false,
+          :image_ref          => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b',
+          :image_ref_alt      => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        }
       end
 
       it 'configures image_ref' do
@@ -38,8 +50,11 @@ describe 'tempest' do
 
     context 'with image_name' do
       let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros' }
+        {
+          :configure_networks => false,
+          :image_name         => 'cirros',
+          :image_name_alt     => 'cirros'
+        }
       end
 
       it 'uses a resource to configure image_ref from image_name' do
@@ -50,10 +65,13 @@ describe 'tempest' do
 
     context 'with image_ref and image_name parameters' do
       let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros',
-          :image_ref      => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b',
-          :image_ref_alt  => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b' }
+        {
+          :configure_networks => false,
+          :image_name         => 'cirros',
+          :image_name_alt     => 'cirros',
+          :image_ref          => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b',
+          :image_ref_alt      => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        }
       end
 
       it_raises 'a Puppet::Error', /either image_name or image_ref/
@@ -61,9 +79,10 @@ describe 'tempest' do
 
     context 'with public_network_id parameter' do
       let :params do
-        { :neutron_available => true,
+        {
           :configure_images  => false,
-          :public_network_id => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b' }
+          :public_network_id => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        }
       end
 
       it 'configures public_network_id' do
@@ -73,9 +92,10 @@ describe 'tempest' do
 
     context 'with public_network_name parameter' do
       let :params do
-        { :neutron_available   => true,
+        {
           :configure_images    => false,
-          :public_network_name => 'public' }
+          :public_network_name => 'public'
+        }
       end
 
       it 'uses a resource to configure public_network_id from public_network_name' do
@@ -85,19 +105,19 @@ describe 'tempest' do
 
     context 'with public_network_id and public_network_name' do
       let :params do
-        { :neutron_available   => true,
+        {
           :configure_images    => false,
           :public_network_name => 'public',
-          :public_network_id   => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b' }
+          :public_network_id   => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        }
       end
 
       it_raises 'a Puppet::Error', /either public_network_id or public_network_name/
     end
 
-    context 'without configures images and neutron_available' do
+    context 'without configures images' do
       let :params do
-        { :configure_images  => false,
-          :neutron_available => true }
+        { :configure_images  => false }
       end
 
       describe "should raise error" do
@@ -107,9 +127,12 @@ describe 'tempest' do
 
     context 'with sahara_plugins' do
       let :params do
-        { :configure_images => false,
-          :sahara_available => true,
-          :sahara_plugins   => ['vanilla'] }
+        {
+          :configure_images   => false,
+          :configure_networks => false,
+          :sahara_available   => true,
+          :sahara_plugins     => ['vanilla'],
+        }
       end
 
       it 'properly configures Sahara plugins in tempest.conf' do
@@ -117,10 +140,27 @@ describe 'tempest' do
       end
     end
 
+    context 'with reseller_admin_role' do
+      let :params do
+        {
+          :configure_images    => false,
+          :configure_networks  => false,
+          :reseller_admin_role => 'admin',
+        }
+      end
+
+      it 'properly sets reseller_admin_role in tempest.conf' do
+        is_expected.to contain_tempest_config('object-storage/reseller_admin_role').with_value('admin')
+      end
+    end
+
     context 'with tempest_roles' do
       let :params do
-        { :configure_images => false,
-          :tempest_roles    => ['Member', 'creator'], }
+        {
+          :configure_images   => false,
+          :configure_networks => false,
+          :tempest_roles      => ['Member', 'creator'],
+        }
       end
 
       it 'properly sets  tempest_roles in tempest.conf' do
@@ -130,8 +170,10 @@ describe 'tempest' do
 
     context 'with ec2api_available parameter' do
       let :params do
-        { :ec2api_available => true,
-          :configure_images => false,
+        {
+          :configure_images   => false,
+          :configure_networks => false,
+          :ec2api_available   => true,
         }
       end
 
@@ -153,7 +195,6 @@ describe 'tempest' do
           :image_name_alt      => 'image name alt',
           :heat_image_name     => 'heat image name',
           :public_network_name => 'network name',
-          :neutron_available   => true,
           :install_from_source => true,
           :setup_venv          => true
         }
@@ -198,6 +239,7 @@ describe 'tempest' do
         it { should contain_class('openstacklib::openstackclient') }
 
         it 'configure tempest config' do
+          is_expected.to contain_tempest_config('service-clients/http_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
@@ -208,11 +250,20 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
+          is_expected.to contain_tempest_config('object-storage/reseller_admin_role').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
+          is_expected.to contain_tempest_config('compute/build_interval').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('compute/build_timeout').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('image/build_interval').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('image/build_timeout').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('network/build_interval').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('network/build_timeout').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('volume/build_interval').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('volume/build_timeout').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('object-storage/build_timeout').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
@@ -238,12 +289,11 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
-          is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
+          is_expected.to contain_tempest_config('network/public_router_id').with(:value => nil)
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
           is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => nil)
           is_expected.to contain_tempest_config('database/db_flavor_ref').with(:value => nil)
@@ -253,7 +303,6 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
-          is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('service_available/bgpvpn').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
@@ -267,6 +316,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/swift').with(:value => false)
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/ironic_inspector').with(:value => false)
           is_expected.to contain_tempest_config('service_available/watcher').with(:value => false)
           is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
@@ -279,7 +329,17 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity-feature-enabled/enforce_scope').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/neutron').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('enforce_scope/nova').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/placement').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/ironic').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/ironic_inspector').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/designate').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/octavia').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/manila').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/ec2_url').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/aws_region').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('aws/image_id').with(:value => nil)
+          is_expected.to contain_tempest_config('aws/ebs_image_id').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => nil)
           is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '3')
           is_expected.to contain_tempest_config('heat_plugin/admin_password').with_secret( true )
@@ -368,9 +428,11 @@ describe 'tempest' do
 
     context 'with img_file set' do
       let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros' ,
-          :img_file       => '/home/stack/myimage.img' }
+        {
+          :configure_images   => false,
+          :configure_networks => false,
+          :img_file           => '/home/stack/myimage.img'
+        }
       end
 
       it 'sets image_file based on img_dir and img_file' do
@@ -380,9 +442,11 @@ describe 'tempest' do
 
     context 'install Tempest from package' do
       let :params do
-        { :install_from_source  => false,
-          :image_name           => 'image name',
-          :image_name_alt       => 'image name alt' }
+        {
+          :configure_images    => false,
+          :configure_networks  => false,
+          :install_from_source => false,
+        }
       end
 
       it 'checks for tempest package' do
@@ -404,10 +468,12 @@ describe 'tempest' do
 
     context 'tempest workspace customization' do
       let :params do
-        { :tempest_workspace   => '/tmp/tempest',
-          :image_name          => 'image name',
-          :image_name_alt      => 'image name alt',
-          :install_from_source => false }
+        {
+          :configure_images    => false,
+          :configure_networks  => false,
+          :tempest_workspace   => '/tmp/tempest',
+          :install_from_source => false
+        }
       end
 
       it 'supports customizes tempest workspace' do
@@ -420,11 +486,12 @@ describe 'tempest' do
     context 'with flavor_name parameters' do
       let :params do
         {
-          :configure_images => false,
-          :flavor_name      => 'm1.tiny',
-          :flavor_name_alt  => 'm1.nano',
-          :db_flavor_name   => 'm1.micro',
-          :heat_flavor_name => 'm1.small',
+          :configure_images   => false,
+          :configure_networks => false,
+          :flavor_name        => 'm1.tiny',
+          :flavor_name_alt    => 'm1.nano',
+          :db_flavor_name     => 'm1.micro',
+          :heat_flavor_name   => 'm1.small',
         }
       end
 
@@ -465,8 +532,11 @@ describe 'tempest' do
     end
 
     let :params do
-      { :configure_images      => false,
-        :manage_tests_packages => true }
+      {
+        :configure_images      => false,
+        :configure_networks    => false,
+        :manage_tests_packages => true
+      }
     end
 
     context 'with when managing tests packages for keystone (required service)' do
@@ -512,12 +582,10 @@ describe 'tempest' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat',
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :dev_packages          => ['python3-dev',
                                        'libxslt1-dev',
@@ -550,7 +618,7 @@ describe 'tempest' do
       end
 
       it_behaves_like 'tempest'
-      if facts[:operatingsystem] != 'Ubuntu'
+      if facts[:os]['name'] != 'Ubuntu'
         it_behaves_like 'tempest with plugins packages'
       end
     end
